@@ -1,3 +1,4 @@
 import os, sys
 sys.path.append(os.path.dirname(os.path.realpath(__file__)))
-from .pysqream_blue import connect
\ No newline at end of file
+from .pysqream_blue import connect, paramstyle
+from .utils import *
\ No newline at end of file
